## Citing

You can also access metadata to cite hstrat in our `CITATION.cff` file [here](https://github.com/mmore500/hstrat/blob/master/CITATION.cff).
Formatted citations were generated via <https://bibtex.online>.

### Software

Please cite hstrat software as

bibtex:
```bibtex
@article{moreno2022hstrat,
  doi = {10.21105/joss.04866},
  url = {https://doi.org/10.21105/joss.04866},
  year = {2022},
  publisher = {The Open Journal},
  volume = {7},
  number = {80},
  pages = {4866},
  author = {Matthew Andres Moreno and Emily Dolson and Charles Ofria},
  title = {hstrat: a Python Package for phylogenetic inference on distributed digital evolution populations},
  journal = {Journal of Open Source Software}
}
```

APA:

> Moreno, M. A., Dolson, E., & Ofria, C. (2022). hstrat: A Python Package for Phylogenetic Inference on Distributed Digital Evolution Populations. Journal of Open Source Software, 7(80), 4866. https://doi.org/10.21105/joss.04866

Chicago:

> Moreno, Matthew Andres, Emily Dolson, and Charles Ofria. "hstrat: A Python Package for Phylogenetic Inference on Distributed Digital Evolution Populations." Journal of Open Source Software 7, no. 80 (2022): 4866. https://doi.org/10.21105/joss.04866.

MLA:

>Moreno, Matthew Andres et al. "hstrat: A Python Package for Phylogenetic Inference on Distributed Digital Evolution Populations." Journal of Open Source Software 7.80 (2022): 4866. https://doi.org/10.21105/joss.04866.


### Methodology

Please cite hereditary stratigraphy methodology as

bibtex:
```bibtex
@inproceedings{10.1162/isal_a_00550,
  author = {Moreno, Matthew Andres and Dolson, Emily and Ofria, Charles},
  title = "{Hereditary Stratigraphy: Genome Annotations to Enable Phylogenetic Inference over Distributed Populations}",
  volume = {ALIFE 2022: The 2022 Conference on Artificial Life},
  series = {ALIFE 2022: The 2022 Conference on Artificial Life},
  year = {2022},
  month = {07},
  booktitle = {Artificial Life Conference Proceedings},
  doi = {10.1162/isal_a_00550},
  url = {https://doi.org/10.1162/isal\_a\_00550},
  note = {64},
  eprint = {https://direct.mit.edu/isal/proceedings-pdf/isal/34/64/2035363/isal\_a\_00550.pdf},
}
```

APA:

> Moreno, M., Dolson, E., & Ofria, C. (2022). Hereditary Stratigraphy: Genome Annotations to Enable Phylogenetic Inference over Distributed Populations. In Artificial Life Conference Proceedings. https://doi.org/10.1162/isal_a_00550

Chicago:

> Moreno, Matthew Andres, Emily, Dolson, and Charles, Ofria. "Hereditary Stratigraphy: Genome Annotations to Enable Phylogenetic Inference over Distributed Populations." In Artificial Life Conference Proceedings. 2022. https://doi.org/10.1162/isal_a_00550

MLA:

> Moreno, Matthew Andres et al. "Hereditary Stratigraphy: Genome Annotations to Enable Phylogenetic Inference over Distributed Populations." Artificial Life Conference Proceedings. 2022. https://doi.org/10.1162/isal_a_00550
